pub struct HookOutcome {
pub fisher: PlayerId,
pub target: PlayerId,
pub rank: Rank,
pub result: HookResult,
}Expand description
The full outcome of a take_turn call, including who fished, who was targeted, what rank was requested, and whether the catch succeeded.
Fields
fisher: PlayerIdtarget: PlayerIdrank: Rankresult: HookResultTrait Implementations
Sourceimpl Clone for HookOutcome
impl Clone for HookOutcome
Sourcefn clone(&self) -> HookOutcome
fn clone(&self) -> HookOutcome
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HookOutcome
impl Debug for HookOutcome
Sourceimpl<'de> Deserialize<'de> for HookOutcome
impl<'de> Deserialize<'de> for HookOutcome
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more