pub struct InactivePlayer {
pub id: PlayerId,
pub completed_books: Vec<CompleteBook>,
}Expand description
A player who no longer has any viable moves. They can still win the game, if they have more Completed Books than any other player at the end of the game
Fields
id: PlayerIdcompleted_books: Vec<CompleteBook>Trait Implementations
Sourceimpl Clone for InactivePlayer
impl Clone for InactivePlayer
Sourcefn clone(&self) -> InactivePlayer
fn clone(&self) -> InactivePlayer
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InactivePlayer
impl Debug for InactivePlayer
Sourceimpl<'de> Deserialize<'de> for InactivePlayer
impl<'de> Deserialize<'de> for InactivePlayer
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more